/* eslint-disable prefer-template */
/* eslint-disable react/jsx-boolean-value */
import React, { useState, useEffect } from 'react';
import { Form, Modal, Input, notification, Radio, Button, message, Upload, Row, Col } from 'antd';
import { AddIntegratedLogin, EditIntegratedLogin } from '@/services/integratedLogin/api';
import { PlusOutlined, LoadingOutlined } from '@ant-design/icons';
import { get, PUBLISH_SERVICE } from '@/services';
import PreviewModal from './PreviewModal';
const { Item } = Form;
const AddModal = props => {
  const { callBackSubmit = () => {}, type, pickItem, visible, onCancel } = props;
  const [loading, setLoading] = useState(false);
  const [radio, setRadio] = useState('');
  const [radio2, setRadio2] = useState('');
  const [flag, setFlag] = useState(1);
  const [form] = Form.useForm();
  const [imageUrl, setImageUrl] = useState();
  const [im, setIm] = useState();
  const [previewModal, setPreviewModal] = useState(false);
  const [keepImgeUrl, setKeepImgeUrl] = useState('');

  useEffect(() => {
    if (visible) {
      if (type === 'edit') {
        console.log(pickItem);
        form.setFieldsValue({
          accountParam: pickItem.AccountParam,
          internetAddress: pickItem.InternetAddress,
          systemClient: pickItem.SystemClient,
          systemName: pickItem.SystemName,
          iconUrl: pickItem.iconUrl,
          subtitle: pickItem.Subtitle,
        });
        if (pickItem.iconUrl) {
          // if (
          //   pickItem.iconUrl.startsWith('CityTemp') ||
          //   pickItem.iconUrl.startsWith('civ_integratedlogin')
          // ) {
          //   setImageUrl(`http://192.168.12.116:8017/${pickItem.iconUrl}`);
          // } else {
          setImageUrl(window.location.origin + `/${pickItem.iconUrl}`);
          setIm(pickItem.iconUrl);
          // }
        } else {
          form.setFieldsValue({ iconUrl: '' });
          setImageUrl('');
          setIm('');
        }
      } else {
        // form.setFieldsValue({ method: 'Get' });
      }
    } else {
      setImageUrl('');
      setIm('');
      setKeepImgeUrl('');
      form.resetFields();
    }
  }, [visible]);
  // 提交
  const onSubmit = () => {
    form.validateFields().then(validate => {
      if (validate) {
        setLoading(true);
        let obj = form.getFieldsValue();
        if (obj.iconUrl.file) {
          obj.iconUrl = obj.iconUrl.file.response.data;
        }
        if (type === 'add') {
          AddIntegratedLogin({
            ...obj,
            accountType: 'Panda',
          })
            .then(res => {
              if (res.code === 0) {
                onCancel();
                setLoading(false);
                callBackSubmit();
                notification.success({
                  message: '提示',
                  duration: 3,
                  description: res.msg || '新增成功',
                });
              } else {
                setLoading(false);
                notification.error({
                  message: '提示',
                  duration: 3,
                  description: res.msg || '新增失败',
                });
              }
            })
            .catch(err => {
              setLoading(false);
            });
        } else {
          EditIntegratedLogin({
            ...obj,
            accountType: 'Panda',
            id: pickItem.ID,
          })
            .then(res => {
              if (res.code === 0) {
                onCancel();
                setLoading(false);
                callBackSubmit();
                notification.success({
                  message: '提示',
                  duration: 3,
                  description: res.msg || '编辑成功',
                });
              } else {
                setLoading(false);
                notification.error({
                  message: '提示',
                  duration: 3,
                  description: res.msg || '编辑失败',
                });
              }
            })
            .catch(err => {
              setLoading(false);
            });
        }
      }
    });
  };

  const layout = {
    layout: 'horizontal',
    labelCol: { span: 4 },
    wrapperCol: { span: 18 },
  };

  const onChange2 = e => {
    setRadio2(e.target.value);
  };

  const onChange = e => {
    setRadio(e.target.value);
  };

  const beforeUpload = file => {
    const isJpgOrPng =
      file.type === 'image/jpeg' ||
      file.type === 'image/png' ||
      file.type === 'image/jpg' ||
      file.type === 'image/gif';
    if (!isJpgOrPng) {
      message.error('只能上传格式为jpeg/png/gif的图片!');
    }
    const isLt2M = file.size / 1024 / 1024 < 2;
    if (!isLt2M) {
      message.error('图片必须小于2MB!');
    }
    return isJpgOrPng && isLt2M;
  };

  const handleChange = info => {
    setKeepImgeUrl('');
    setIm('');
    if (info.file.status === 'uploading') {
      setLoading(true);
      return;
    }

    if (info.file.status === 'done') {
      getBase64(info.file.originFileObj, url => {
        setLoading(false);
        setImageUrl(url);
      });
    }
  };

  const getBase64 = (img, callback) => {
    const reader = new FileReader();
    reader.addEventListener('load', () => callback(reader.result));
    reader.readAsDataURL(img);
  };

  const uploadButton = (
    <div>
      {loading ? <LoadingOutlined /> : <PlusOutlined />}
      <div
        style={{
          marginTop: 8,
        }}
      >
        上传
      </div>
    </div>
  );

  const pictruePreview = () => {
    setPreviewModal(true);
  };

  const onOk = props => {
    if (props) {
      console.log(props.path);
      console.log(process.env.PROXY);
      setImageUrl(window.location.origin + `/${props.path}`);
      setIm(props.path);
      setKeepImgeUrl(props.path);
      form.setFieldsValue({ iconUrl: `${props.path}` });
    }
  };

  return (
    <Modal
      title={type === 'add' ? '新增集成网站' : '编辑集成网站'}
      style={{ top: '150px' }}
      width="700px"
      destroyOnClose
      maskClosable={false}
      cancelText="取消"
      okText="确认"
      {...props}
      onOk={() => onSubmit()}
      confirmLoading={loading}
      forceRender={true}
      getContainer={false}
    >
      <Form form={form} {...layout}>
        <Item label="名称" name="systemName" rules={[{ required: true, message: '请输入名称' }]}>
          <Input allowClear style={{ width: '100%' }} placeholder="请输入名称" />
        </Item>
        <Item label="标识" name="systemClient" rules={[{ required: true, message: '请输入标识' }]}>
          <Input allowClear placeholder="请输入标识" />
        </Item>
        <Item label="副标题" name="subtitle" rules={[{ required: true, message: '请输入副标题' }]}>
          <Input allowClear placeholder="建议使用英文" />
        </Item>
        {/* <Item
          label="内网地址"
          name="intranetAddress"
          rules={[{ required: true, message: '请输入内网地址' }]}
        >
          <Input allowClear />
        </Item> */}
        <Item
          label="访问地址"
          name="internetAddress"
          rules={[{ required: true, message: '请输入外网地址' }]}
        >
          <Input
            allowClear
            placeholder="示例：http://192.168.12.116:8500/civbase/user/noscret?client=city"
          />
        </Item>
        {/* <Item label="请求方式" name="method">
          <Radio.Group onChange={onChange2} value={radio2}>
            <Radio value="Get">Get</Radio>
            <Radio value="Post">Post</Radio>
          </Radio.Group>
        </Item> */}
        <Item
          label="账号参数"
          name="accountParam"
          rules={[{ required: true, message: '请输入参数' }]}
        >
          <Input allowClear />
          {/* <Radio.Group onChange={onChange} value={radio}>
            <Radio value={0}>使用熊猫身份</Radio>
            <Radio value={1}>使用令牌</Radio>
          </Radio.Group> */}
        </Item>
        <Row>
          <Col span={10}>
            <Item
              label="图标"
              name="iconUrl"
              style={{ height: '112px' }}
              labelCol={{ span: 10 }}
              rules={[
                {
                  required: true,
                  message: '请选择图标',
                },
              ]}
            >
              <Upload
                name="singleFile"
                listType="picture-card"
                showUploadList={false}
                beforeUpload={beforeUpload}
                action={`${window.location.origin}${PUBLISH_SERVICE}/UploadSingleFile`}
                onChange={handleChange}
              >
                {imageUrl ? (
                  <img
                    src={imageUrl}
                    alt="singleFile"
                    style={{
                      width: '90%',
                    }}
                  />
                ) : (
                  uploadButton
                )}
              </Upload>
            </Item>
          </Col>
          <Col span={12}>
            <Item>
              <Button type="primary" onClick={pictruePreview} style={{ marginTop: '33px' }}>
                从图片库中选择
              </Button>
            </Item>
          </Col>
        </Row>
        {/* <Item
          label="单点登陆地址"
          name="loginUrl"
          rules={[{ required: true, message: '请输入单点登录地址' }]}
        >
          <Input allowClear />
        </Item> */}
      </Form>
      <PreviewModal
        visible={previewModal}
        onCancel={() => {
          setPreviewModal(false);
        }}
        imageUrl={im}
        keepImgeUrl={keepImgeUrl}
        callBackSubmit={onOk}
      />
    </Modal>
  );
};
export default AddModal;
