/* eslint-disable prefer-template */
/* eslint-disable no-undef */
import React, { useState, useEffect } from 'react';
import {
  Tooltip,
  Spin,
  Modal,
  Input,
  Space,
  Button,
  Popconfirm,
  Table,
  notification,
  Image,
} from 'antd';
import { GetIntegratedLogin, DelIntegratedLogin } from '@/services/integratedLogin/api';
import { EditTwoTone, DeleteOutlined, PlusOutlined, SyncOutlined } from '@ant-design/icons';
import styles from './integrate.less';
import AddModal from './AddModal';
import Master from './Master';

const Integrate = () => {
  const [loading, setLoading] = useState(false);
  const [tableData, setTableData] = useState([]);
  const [showSearchStyle, setShowSearchStyle] = useState(false); // 是否显示模糊查询样式
  const [searchWord, setSearchWord] = useState(''); // 关键字
  const [flag, setFlag] = useState(0);
  const [addVisible, setAddVisible] = useState(false);
  const [pickItem, setPickItem] = useState('');
  const [type, setType] = useState('');
  const [masterVisible, setMasterVisible] = useState(false);

  const { Search } = Input;

  useEffect(() => {
    getData();
  }, [flag]);

  const columns = [
    {
      title: '序号',
      key: 'id ',
      dataIndex: 'id',
      render: (text, record, index) => (
        <Space>
          <span>{index + 1}</span>
        </Space>
      ),
      width: 60,
      align: 'center',
    },
    {
      title: '名称',
      dataIndex: 'SystemName',
      key: 'SystemName',
      align: 'center',
      ellipsis: true,
      render: (text, record) => (
        <span>
          <Tooltip placement="top" title={text}>
            {searchStyle(text)}
          </Tooltip>
        </span>
      ),
    },
    {
      title: '标识',
      dataIndex: 'SystemClient',
      key: 'SystemClient',
      align: 'center',
      ellipsis: true,
      render: (text, record) => (
        <span>
          <Tooltip placement="top" title={text}>
            {searchStyle(text)}
          </Tooltip>
        </span>
      ),
    },
    // {
    //   title: '内网地址',
    //   dataIndex: 'IntranetAddress',
    //   key: 'IntranetAddress',
    //   align: 'center',
    //   width: 400,
    //   ellipsis: true,
    //   render: (text, record) => (
    //     <span>
    //       <Tooltip placement="top" title={text}>
    //         {text}
    //       </Tooltip>
    //     </span>
    //   ),
    // },
    {
      title: '外网地址',
      dataIndex: 'InternetAddress',
      key: 'InternetAddress',
      ellipsis: true,
      align: 'center',
      maxWidth: 600,
      onCell: () => ({
        style: {
          maxWidth: 600,
          overflow: 'hidden',
          whiteSpace: 'nowrap',
          textOverflow: 'ellipsis',
          cursor: 'pointer',
        },
      }),
      render: (text, record) => (
        <span>
          <Tooltip placement="top" title={text}>
            {text}
          </Tooltip>
        </span>
      ),
    },
    {
      title: '图标',
      dataIndex: 'iconUrl',
      key: 'iconUrl',
      align: 'center',
      width: 200,
      render: (text, record) => {
        console.log(text);
        if (text) {
          // if (text.startsWith('CityTemp') || text.startsWith('civ_integratedlogin')) {
          //   return <Image src={`http://192.168.12.116:8017/${text}`} height="50px" />;
          // } else {
          return <Image src={window.location.origin + `/${text}`} height="50px" />;
          // }
        }
      },
    },
    {
      title: '参数',
      dataIndex: 'AccountParam',
      key: 'AccountParam',
      align: 'center',
      width: 200,
    },
    {
      title: '操作',
      key: 'action',
      width: 100,
      align: 'center',
      render: record => (
        <Space size="middle">
          <Tooltip title="编辑">
            <EditTwoTone onClick={() => edit(record)} style={{ fontSize: '16px' }} />
          </Tooltip>
          <Tooltip title="删除">
            <Popconfirm
              placement="bottomRight"
              title={
                <p>
                  即将删除 <span>{record.loginName}</span>
                  ，是否确认删除？
                </p>
              }
              okText="确认"
              cancelText="取消"
              onConfirm={() => dele(record)}
            >
              <DeleteOutlined style={{ fontSize: '16px', color: '#e86060' }} />
            </Popconfirm>
          </Tooltip>
        </Space>
      ),
    },
  ];

  // 模糊查询匹配的样式
  const searchStyle = val => {
    let n;
    if (showSearchStyle) {
      n = val.replace(new RegExp(searchWord, 'g'), `<span style='color:red'>${searchWord}</span>`);
    } else {
      n = val;
    }
    return <div dangerouslySetInnerHTML={{ __html: n }} />;
  };

  const getData = () => {
    setLoading(true);
    GetIntegratedLogin().then(resnew => {
      if (resnew.code === 0) {
        setTableData(resnew.data);
      } else {
        notification.error({
          message: '获取失败',
          description: resnew.msg,
        });
      }
      setLoading(false);
    });
  };

  const add = () => {
    setType('add');
    setAddVisible(true);
  };

  const edit = e => {
    setType('edit');
    setPickItem(e);
    setAddVisible(true);
  };

  const dele = e => {
    setPickItem(e);
    setLoading(true);
    DelIntegratedLogin({
      ID: e.ID,
    }).then(res => {
      if (res.code === 0) {
        setFlag(flag + 1);
        notification.success({
          message: '删除成功',
          description: res.msg,
        });
      } else {
        notification.error({
          message: '删除失败',
          description: res.msg,
        });
      }
      setLoading(false);
    });
  };

  const submitSearch = () => {
    setLoading(true);
    GetIntegratedLogin({ searchKey: searchWord }).then(resnew => {
      if (resnew.code === 0) {
        setTableData(resnew.data);
        setShowSearchStyle(true);
      } else {
        notification.error({
          message: '获取失败',
          description: resnew.msg,
        });
      }
      setLoading(false);
    });
  };

  const handleReset = () => {
    setSearchWord('');
    setShowSearchStyle(false);
    setLoading(true);
    GetIntegratedLogin({ searchKey: '' }).then(resnew => {
      if (resnew.code === 0) {
        setTableData(resnew.data);
      } else {
        notification.error({
          message: '获取失败',
          description: resnew.msg,
        });
      }
      setLoading(false);
    });
  };

  const handleSearch = e => {
    setSearchWord(e.target.value);
  };

  const onSubmit = () => {
    setFlag(flag + 1);
  };

  const masterStation = () => {
    setMasterVisible(true);
  };

  return (
    <div className={styles.Integrate}>
      <div className={styles.head}>
        <div className={styles.head1}>
          <span>快速搜索：</span>
          <Search
            style={{ width: 260 }}
            placeholder="请输入名称，标识"
            onSearch={submitSearch}
            onChange={e => handleSearch(e)}
            enterButton
            value={searchWord}
          />
          <Button icon={<SyncOutlined />} onClick={handleReset} style={{ marginLeft: '20px' }}>
            重置
          </Button>
          <Button
            icon={<PlusOutlined className={styles.icon} />}
            onClick={add}
            style={{
              verticalAlign: 'middle',
              marginLeft: '40px',
            }}
          >
            新增
          </Button>
        </div>
        <Button
          type="primary"
          onClick={masterStation}
          style={{
            float: 'right',
            verticalAlign: 'middle',
          }}
        >
          集成登录网站配置
        </Button>
      </div>
      <Spin spinning={loading} tip="loading">
        <div className={styles.table}>
          <Table
            size="small"
            bordered
            rowKey={record => record.Id}
            columns={columns}
            dataSource={tableData}
            scroll={{ y: 'calc(100vh - 200px)', x: 'max-content' }}
            onRow={record => ({
              onDoubleClick: event => {
                event.stopPropagation();
                edit(record);
              }, // 双击
            })}
            pagination={false}
          />
        </div>
      </Spin>
      <AddModal
        visible={addVisible}
        pickItem={pickItem}
        onCancel={() => setAddVisible(false)}
        type={type}
        callBackSubmit={onSubmit}
      />
      <Master visible={masterVisible} onCancel={() => setMasterVisible(false)} />
    </div>
  );
};

export default Integrate;
